@@ -1,4 +1,4 @@
-
+// Copyright (c) 2002-2003 Rob Kaper <cap@capsi.com>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -21,11 +21,21 @@
 #include <kdialog.h>
 #include <klocale.h>
 #include <kiconloader.h>
+#include <knotifyclient.h>
 
-#include "selectgame_widget.moc"
+#include <atlantic_core.h>
+#include <game.h>
+#include <player.h>
 
-SelectGame::SelectGame(QWidget *parent, const char *name) : QWidget(parent, name)
+#include "selectgame_widget.h"
+
+SelectGame::SelectGame(AtlanticCore *atlanticCore, QWidget *parent, const char *name) : QWidget(parent, name)
 {
+	m_atlanticCore = atlanticCore;
+
+	connect(m_atlanticCore, SIGNAL(createGUI(Game *)), this, SLOT(addGame(Game *)));
+	connect(m_atlanticCore, SIGNAL(removeGUI(Game *)), this, SLOT(delGame(Game *)));
+
 	m_mainLayout = new QVBoxLayout(this, KDialog::marginHint());
 	Q_CHECK_PTR(m_mainLayout);
 
@@ -35,10 +45,10 @@ SelectGame::SelectGame(QWidget *parent, const char *name) : QWidget(parent, name
 
 	// List of games
 	m_gameList = new KListView(groupBox, "m_gameList");
-	m_gameList->addColumn(QString(i18n("Game")));
-	m_gameList->addColumn(QString(i18n("Description")));
-	m_gameList->addColumn(QString(i18n("Id")));
-	m_gameList->addColumn(QString(i18n("Players")));
+	m_gameList->addColumn(i18n("Game"));
+	m_gameList->addColumn(i18n("Description"));
+	m_gameList->addColumn(i18n("Id"));
+	m_gameList->addColumn(i18n("Players"));
 	m_gameList->setAllColumnsShowFocus(true);
 //	m_mainLayout->addWidget(m_gameList);
 
@@ -56,85 +66,101 @@ SelectGame::SelectGame(QWidget *parent, const char *name) : QWidget(parent, name
 
 	buttonBox->addItem(new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum));
 
-	m_connectButton = new KPushButton(SmallIcon("forward"), i18n("Create Game"), this);
+	m_connectButton = new KPushButton(SmallIconSet("forward"), i18n("Create Game"), this);
 	m_connectButton->setEnabled(false);
 	buttonBox->addWidget(m_connectButton);
 
 	connect(m_connectButton, SIGNAL(clicked()), this, SLOT(connectClicked()));
 
-    // Status indicator
-	m_statusLabel = new QLabel(this);
-	m_statusLabel->setText(i18n("Retrieving game list..."));
-	m_mainLayout->addWidget(m_statusLabel);
 }
 
-void SelectGame::slotGameListClear()
+void SelectGame::addGame(Game *game)
 {
-	m_gameList->clear();
-	validateConnectButton();
-//	emit statusChanged();
-}
+	connect(game, SIGNAL(changed(Game *)), this, SLOT(updateGame(Game *)));
 
-void SelectGame::slotGameListEndUpdate()
-{
-	m_statusLabel->setText(i18n("Retrieved game list."));
-}
-
-void SelectGame::slotGameListAdd(QString gameId, QString name, QString description, QString players, QString gameType, bool canBeJoined)
-{
-	if (gameId == "-1")
+	if (game->id() == -1)
 	{
-		QListViewItem *item = new QListViewItem(m_gameList, i18n("Create new %1 Game").arg(name), description, QString::null, QString::null, gameType);
+		QListViewItem *item = new QListViewItem( m_gameList, i18n("Create a new %1 Game").arg(game->name()), game->description(), QString::null, QString::null, game->type() );
 		item->setPixmap(0, QPixmap(SmallIcon("filenew")));
 	}
 	else
 	{
-		QListViewItem *item = new QListViewItem(m_gameList, i18n("Join %1 Game #%2").arg(name).arg(gameId), description, gameId, players, gameType);
-		item->setPixmap(0, QPixmap(SmallIcon("atlantik")));
-		item->setEnabled(canBeJoined);
+		Player *master = game->master();
+		QListViewItem *item = new QListViewItem( m_gameList, i18n("Join %1's %2 Game").arg( (master ? master->name() : QString::null), game->name() ), game->description(), QString::number(game->id()), QString::number(game->players()), game->type() );
+		item->setPixmap( 0, QPixmap(SmallIcon("atlantik")) );
+		item->setEnabled(game->canBeJoined());
+
+		KNotifyClient::event(winId(), "newgame");
+
+		connect(master, SIGNAL(changed(Player *)), this, SLOT(playerChanged(Player *)));
 	}
 
+//	validateConnectButton();
+}
+
+void SelectGame::delGame(Game *game)
+{
+	QListViewItem *item = findItem(game);
+	if (!item)
+		return;
+
+	delete item;
+
 	validateConnectButton();
 }
 
-void SelectGame::slotGameListEdit(QString gameId, QString name, QString description, QString players, QString gameType, bool canBeJoined)
+void SelectGame::updateGame(Game *game)
 {
-	QListViewItem *item = m_gameList->firstChild();
-	while (item)
+	QListViewItem *item = findItem(game);
+	if (!item)
+		return;
+
+	item->setText( 1, game->description() );
+
+	if (game->id() == -1)
+		item->setText(0, i18n("Create a new %1 Game").arg(game->name()));
+	else
 	{
-		if (item->text(2) == gameId)
-		{
-			if (!name.isEmpty())
-				item->setText(0, i18n("Join %1 Game #%2").arg(name).arg(gameId));
-			if (!description.isEmpty())
-				item->setText(1, description);
-			item->setText(3, players);
-			if (!gameType.isEmpty())
-				item->setText(4, gameType);
-			item->setEnabled(canBeJoined);
-			m_gameList->triggerUpdate();
-			return;
-		}
-		item = item->nextSibling();
+		Player *master = game->master();
+		item->setText( 0, i18n("Join %1's %2 Game").arg( (master ? master->name() : QString::null), game->name() ) );
+		item->setText( 3, QString::number( game->players() ) );
+		item->setEnabled( game->canBeJoined() );
+
+		connect(master, SIGNAL(changed(Player *)), this, SLOT(playerChanged(Player *)));
 	}
+	m_gameList->triggerUpdate();
+
 	validateConnectButton();
-//	emit statusChanged();
 }
 
-void SelectGame::slotGameListDel(QString gameId)
+void SelectGame::playerChanged(Player *player)
 {
 	QListViewItem *item = m_gameList->firstChild();
+	Game *game = 0;
+
 	while (item)
 	{
-		if (item->text(2) == gameId)
+		game = m_atlanticCore->findGame( item->text(2).toInt() );
+		if ( game && game->master() == player )
 		{
-			delete item;
+			item->setText( 0, i18n("Join %1's %2 Game").arg( player->name(), game->name() ) );
 			return;
 		}
 		item = item->nextSibling();
 	}
-	validateConnectButton();
-//	emit statusChanged();
+}
+
+QListViewItem *SelectGame::findItem(Game *game)
+{
+	QListViewItem *item = m_gameList->firstChild();
+	while (item)
+	{
+		if ( (game->id() == -1 || item->text(2) == QString::number(game->id())) && item->text(4) == game->type() )
+			return item;
+
+		item = item->nextSibling();
+	}
+	return 0;
 }
 
 void SelectGame::validateConnectButton()
@@ -162,3 +188,5 @@ void SelectGame::connectClicked()
 			emit newGame(item->text(4));
 	}
 }
+
+#include "selectgame_widget.moc"
