@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbggame.h,v 1.3 2003/03/07 22:05:56 waba Exp $
+  $Id: kbggame.h,v 1.4 2005/01/11 12:51:20 mlaurent Exp $
 
 */
 
@@ -29,7 +29,7 @@
 #endif
 
 #include <kgame.h>
-
+#include <kdemacros.h>
 class QObject;
 class KPlayer;
 
@@ -37,7 +37,7 @@ class KPlayer;
  *
  *
  */
-class KBgGame : public KGame
+class KDE_EXPORT KBgGame : public KGame
 {
     Q_OBJECT
 
