@@ -17,7 +17,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-  $Id: kbgoffline.cpp,v 1.12 2003/03/07 22:09:21 waba Exp $
+  $Id: kbgoffline.cpp,v 1.15 2004/12/01 13:47:56 binner Exp $
 
 */
 
@@ -120,7 +120,7 @@ KBgEngineOffline::KBgEngineOffline(QWidget *parent, QString *name, QPopupMenu *p
     /*
      * Create engine specific actions
      */
-    d->mNew  = new KAction(i18n("&New Game"),    0, this, SLOT(newGame()),  this);
+    d->mNew  = new KAction(i18n("&New Game..."),    0, this, SLOT(newGame()),  this);
     d->mSwap = new KAction(i18n("&Swap Colors"), 0, this, SLOT(swapColors()), this);
 
     d->mEdit = new KToggleAction(i18n("&Edit Mode"), 0, this,
@@ -618,20 +618,16 @@ void KBgEngineOffline::rollDiceBackend(const int w, const int a, const int b)
         emit allowMoving(false);
         break;
     case  0:
-        emit infoText(i18n("%1, you can't move.").
+        emit infoText(i18n("%1, you cannot move.").
                       arg((w == US) ? d->mName[0] : d->mName[1]));
         if (cl)
             ct->start(cl, true);
         emit allowMoving(false);
         break;
-    case  1:
-        emit infoText(i18n("%1, please move 1 piece.").
-                      arg((w == US) ? d->mName[0] : d->mName[1]));
-        emit allowMoving(true);
-        break;
+//    case  1:
     default:
-        emit infoText(i18n("%1, please move %2 pieces.").
-                      arg((w == US) ? d->mName[0] : d->mName[1]).arg(d->mMove));
+        emit infoText(QString((w == US) ? d->mName[0] : d->mName[1]) +
+	i18n(", please move 1 piece.",", please move %n pieces.",d->mMove));
         emit allowMoving(true);
         break;
     }
