@@ -3,11 +3,9 @@
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kdeversion.h>
-#include <kedittoolbar.h>
 #include <kfiledialog.h>
 #include <kglobal.h>
 #include <kio/netaccess.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <kmainwindow.h>
 #include <kmimetype.h>
@@ -52,10 +50,6 @@
 Kolf::Kolf()
     : KMainWindow(0, "Kolf")
 {
-#if KDE_VERSION > 305
-	setStandardToolBarMenuEnabled(true);
-#endif
-
 	competition = false;
 	game = 0;
 	editor = 0;
@@ -74,7 +68,6 @@ Kolf::Kolf()
 	layout = new QGridLayout(dummy, 3, 1);
 
 	resize(420, 480);
-	setAutoSaveSettings("TopLevelWindow");
 }
 
 Kolf::~Kolf()
@@ -89,8 +82,6 @@ void Kolf::initGUI()
 	newAction = KStdGameAction::gameNew(this, SLOT(newGame()), actionCollection());
 	newAction->setText(newAction->text() + QString("..."));
 
-	(void) KStdAction::keyBindings(this, SLOT(keyBindings()), actionCollection());
-	(void) KStdAction::configureToolbars(this, SLOT(configureToolBars()), actionCollection());
 	endAction = KStdGameAction::end(this, SLOT(closeGame()), actionCollection());
 	printAction = KStdGameAction::print(this, SLOT(print()), actionCollection());
 
@@ -124,24 +115,29 @@ void Kolf::initGUI()
 	randAction = new KAction(i18n("&Random Hole"), "goto", 0, this, SLOT(emptySlot()), actionCollection(), "randhole");
 
 	useMouseAction = new KToggleAction(i18n("Enable &Mouse for Moving Putter"), 0, this, SLOT(emptySlot()), actionCollection(), "usemouse");
+	useMouseAction->setCheckedState(i18n("Disable &Mouse for Moving Putter"));
 	connect(useMouseAction, SIGNAL(toggled(bool)), this, SLOT(useMouseChanged(bool)));
 	KConfig *config = kapp->config();
 	config->setGroup("Settings");
 	useMouseAction->setChecked(config->readBoolEntry("useMouse", true));
 
 	useAdvancedPuttingAction = new KToggleAction(i18n("Enable &Advanced Putting"), 0, this, SLOT(emptySlot()), actionCollection(), "useadvancedputting");
+	useAdvancedPuttingAction->setCheckedState(i18n("Disable &Advanced Putting"));
 	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), this, SLOT(useAdvancedPuttingChanged(bool)));
 	useAdvancedPuttingAction->setChecked(config->readBoolEntry("useAdvancedPutting", false));
 
 	showInfoAction = new KToggleAction(i18n("Show &Info"), "viewmag+", CTRL+Key_I, this, SLOT(emptySlot()), actionCollection(), "showinfo");
+	showInfoAction->setCheckedState(i18n("Hide &Info"));
 	connect(showInfoAction, SIGNAL(toggled(bool)), this, SLOT(showInfoChanged(bool)));
 	showInfoAction->setChecked(config->readBoolEntry("showInfo", false));
 
 	showGuideLineAction = new KToggleAction(i18n("Show Putter &Guideline"), 0, this, SLOT(emptySlot()), actionCollection(), "showguideline");
+	showGuideLineAction->setCheckedState(i18n("Hide Putter &Guideline"));
 	connect(showGuideLineAction, SIGNAL(toggled(bool)), this, SLOT(showGuideLineChanged(bool)));
 	showGuideLineAction->setChecked(config->readBoolEntry("showGuideLine", true));
 
-	(void) new KToggleAction(i18n("Enable All Dialog Boxes"), 0, this, SLOT(enableAllMessages()), actionCollection(), "enableAll");
+	KToggleAction *act=new KToggleAction(i18n("Enable All Dialog Boxes"), 0, this, SLOT(enableAllMessages()), actionCollection(), "enableAll");
+	act->setCheckedState(i18n("Disable All Dialog Boxes"));
 
 	soundAction = new KToggleAction(i18n("Play &Sounds"), 0, this, SLOT(emptySlot()), actionCollection(), "sound");
 	connect(soundAction, SIGNAL(toggled(bool)), this, SLOT(soundChanged(bool)));
@@ -153,7 +149,8 @@ void Kolf::initGUI()
 	aboutAction = new KAction(i18n("&About Course"), 0, this, SLOT(emptySlot()), actionCollection(), "aboutcourse");
 	tutorialAction = new KAction(i18n("&Tutorial"), 0, this, SLOT(tutorial()), actionCollection(), "tutorial");
 
-	createGUI();
+	statusBar();
+	setupGUI();
 }
 
 bool Kolf::queryClose()
@@ -747,7 +744,7 @@ void Kolf::soundChanged(bool yes)
 
 void Kolf::initPlugins()
 {
-	//kdDebug() << "initPlugins" << endl;
+	//kdDebug(12007) << "initPlugins" << endl;
 	if (game)
 		game->pause();
 
@@ -783,7 +780,7 @@ void Kolf::initPlugins()
 		game->unPause();
 	}
 
-	//kdDebug() << "end of initPlugins" << endl;
+	//kdDebug(12007) << "end of initPlugins" << endl;
 }
 
 void Kolf::showPlugins()
@@ -802,26 +799,6 @@ void Kolf::showPlugins()
 	KMessageBox::information(this, text, i18n("Plugins"));
 }
 
-void Kolf::keyBindings()
-{
-	KKeyDialog::configure(actionCollection());
-}
-
-void Kolf::configureToolBars()
-{
-	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
-
-	KEditToolbar dlg(actionCollection());
-	connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(newToolBarConfig()));
-	dlg.exec();
-}
-
-void Kolf::newToolBarConfig()
-{
-	createGUI();
-	applyMainWindowSettings(KGlobal::config(), "TopLevelWindow");
-}
-
 void Kolf::enableAllMessages()
 {
 	KMessageBox::enableAllMessages();
