@@ -181,7 +181,6 @@ void HighscoresWidget::changeTab(int i)
 
 void HighscoresWidget::showURL(const QString &url) const
 {
-    KFileOpenWithHandler foo;
     (void)new KRun(KURL(url));
 }
 
@@ -254,7 +253,7 @@ void HighscoresDialog::slotUser2()
 {
     KURL url = KFileDialog::getSaveURL(QString::null, QString::null, this);
     if ( url.isEmpty() ) return;
-    if ( KIO::NetAccess::exists(url) ) {
+    if ( KIO::NetAccess::exists(url, true, this) ) {
         KGuiItem gi = KStdGuiItem::save();
         gi.setText(i18n("Overwrite"));
         int res = KMessageBox::warningYesNo(this,
@@ -265,7 +264,7 @@ void HighscoresDialog::slotUser2()
     KTempFile tmp;
     internal->exportHighscores(*tmp.textStream());
     tmp.close();
-    KIO::NetAccess::upload(tmp.name(), url);
+    KIO::NetAccess::upload(tmp.name(), url, this);
     tmp.unlink();
 }
 
