@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgame.h,v 1.59 2004/03/26 12:51:18 raabe Exp $
+    $Id: kgame.h,v 1.60 2005/01/11 12:51:22 mlaurent Exp $
 */
 #ifndef __KGAME_H_
 #define __KGAME_H_
@@ -28,7 +28,7 @@
 #include <qvaluelist.h>
 
 #include "kgamenetwork.h"
-
+#include <kdemacros.h>
 class KRandomSequence;
 
 class KPlayer;
@@ -59,7 +59,7 @@ class KGamePrivate;
  * @author Martin Heni <martin@heni-online.de>
  *
  */
-class KGame : public KGameNetwork
+class KDE_EXPORT KGame : public KGameNetwork
 {
   Q_OBJECT
 
