@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgameio.cpp,v 1.30 2003/02/21 15:11:01 andreas Exp $
+    $Id: kgameio.cpp,v 1.31 2004/08/26 22:29:03 andreas Exp $
 */
 
 #include "kgameio.h"
@@ -221,7 +221,7 @@ bool KGameMouseIO::eventFilter( QObject *o, QEvent *e )
      QDataStream stream(buffer,IO_WriteOnly);
      bool eatevent=false;
      emit signalMouseEvent(this,stream,k,&eatevent);
-     kdDebug(11001) << "################# eatevent=" << eatevent << endl;
+//     kdDebug(11001) << "################# eatevent=" << eatevent << endl;
      QDataStream msg(buffer,IO_ReadOnly);
      if (eatevent && sendInput(msg))
      {
