@@ -70,7 +70,6 @@ void KMessageClient::setServer (const QString &host, Q_UINT16 port)
 
 void KMessageClient::setServer (KMessageServer *server)
 {
- 
   KMessageDirect *serverIO = new KMessageDirect ();
   setServer (new KMessageDirect (serverIO));
   server->addClient (serverIO);
@@ -126,6 +125,16 @@ bool KMessageClient::isNetwork () const
   return isConnected() ? d->connection->isNetwork() : false;
 }
 
+Q_UINT16 KMessageClient::peerPort () const
+{
+ return d->connection ? d->connection->peerPort() : 0;
+}
+
+QString KMessageClient::peerName () const
+{
+ return d->connection ? d->connection->peerName() : QString::fromLatin1("localhost");
+}
+
 // --------------------- Sending messages
 
 void KMessageClient::sendServerMessage (const QByteArray &msg)
@@ -145,7 +154,7 @@ void KMessageClient::sendBroadcast (const QByteArray &msg)
   buffer.open (IO_WriteOnly);
   QDataStream stream (&buffer);
 
-  stream << KMessageServer::REQ_BROADCAST;
+  stream << static_cast<Q_UINT32> ( KMessageServer::REQ_BROADCAST );
   buffer.QIODevice::writeBlock (msg);
   sendServerMessage (sendBuffer);
 }
@@ -157,7 +166,7 @@ void KMessageClient::sendForward (const QByteArray &msg, const QValueList <Q_UIN
   buffer.open (IO_WriteOnly);
   QDataStream stream (&buffer);
 
-  stream << KMessageServer::REQ_FORWARD << clients;
+  stream << static_cast<Q_UINT32>( KMessageServer::REQ_FORWARD ) << clients;
   buffer.QIODevice::writeBlock (msg);
   sendServerMessage (sendBuffer);
 }
@@ -313,7 +322,7 @@ void KMessageClient::removeBrokenConnection ()
 {
   kdDebug (11001) << k_funcinfo << ": timer single shot for removeBrokenConnection"<<this << endl;
   // MH We cannot directly delete the socket. otherwise QSocket crashes
-	QTimer::singleShot( 0, this, SLOT(removeBrokenConnection2()) );
+  QTimer::singleShot( 0, this, SLOT(removeBrokenConnection2()) );
   return;
 }
 
